@@ -17,10 +17,9 @@ extern bool debug;
 // BranchObj
 /////////////////////////////////////////////////////////////////
 
-BranchObj::BranchObj (QGraphicsScene* s,TreeItem *ti):OrnamentedObj (s,ti)
+BranchObj::BranchObj (QGraphicsItem *parent,TreeItem *ti):OrnamentedObj (parent,ti)
 {
-    //qDebug ()<< "Const BranchObj (s,ti) ti="<<ti;
-    scene=s;
+    //qDebug ()<< "Const BranchObj  (s,ti) ti="<<ti;
     treeItem=ti;
     BranchItem *pi=(BranchItem*)(ti->parent());
     if (pi && pi!=ti->getModel()->getRootItem() )
@@ -32,7 +31,7 @@ BranchObj::BranchObj (QGraphicsScene* s,TreeItem *ti):OrnamentedObj (s,ti)
 
 BranchObj::~BranchObj ()
 {
-    //qDebug()<< "Destr BranchObj of "<<this<<" ("<<treeItem->getHeading()<<")";
+    //qDebug()<< "Destr BranchObj  of "<<this;
 
     // If I'm animated, I need to un-animate myself first
     if (anim.isAnimated() )
@@ -47,11 +46,7 @@ BranchObj::~BranchObj ()
 
 void BranchObj::init () 
 {
-    if (parObj)
-    {
-	absPos=getRandPos();
-	absPos+=parObj->getChildPos();
-    }
+    if (parObj) absPos=parObj->getChildPos();
 }
 
 void BranchObj::copy (BranchObj* other)
@@ -65,7 +60,6 @@ void BranchObj::copy (BranchObj* other)
 
 void BranchObj::clear() 
 {
-    //setVisibility (true); //FIXME-4 needed?
 }
 
 void BranchObj::setParObjTmp(LinkableMapObj* dst, QPointF m, int off)	
@@ -160,11 +154,12 @@ void BranchObj::unsetParObjTmp()
     }	    
 }
 
-void BranchObj::setVisibility(bool v, int toDepth)
+void BranchObj::setVisibility(bool v, int toDepth) 
 {
     BranchItem *bi=(BranchItem*)treeItem;
     if (bi->depth() <= toDepth)
     {
+//qDebug()<<"   * BO::setVis v="<<v<<bi->getHeading();
 	frame->setVisibility(v);
 	heading->setVisibility(v);
 	systemFlags->setVisibility(v);
@@ -179,12 +174,11 @@ void BranchObj::setVisibility(bool v, int toDepth)
 	// Only change children, if I am not scrolled
 	if (! bi->isScrolled() && (bi->depth() < toDepth))
 	{
-	    // Now go recursivly through all children //FIXME-3 are there multiple calls for lower level items???
+	    // Now go recursivly through all children 
 	    for (i=0; i<treeItem->branchCount(); ++i)
 		treeItem->getBranchObjNum(i)->setVisibility (v,toDepth);    
 	}
     } // depth <= toDepth   
-    requestReposition();
 }   
 
 void BranchObj::setVisibility(bool v)
@@ -246,12 +240,13 @@ void BranchObj::moveBy (QPointF p)
     moveBy (p.x(), p.y());
 }
 
+void QGraphicsItem::paint(QPainter*, const QStyleOptionGraphicsItem*, QWidget*)
+{
+}
 
-void BranchObj::positionBBox()
+void BranchObj::positionBBox() // FIXME-2 consider dimensions of frame (thickness, geometry, padding...
 {
     QPointF ap=getAbsPos();
-    //ap.setX(ap.x()+frame->getPadding());
-    //ap.setY(ap.y()+frame->getPadding());
     bbox.moveTopLeft (ap);
     positionContents();
 
@@ -443,7 +438,7 @@ void BranchObj::updateData()
 void BranchObj::setDefAttr (BranchModification mod, bool keepFrame)
 {
     QFont font=treeItem->getModel()->getMapDefaultFont();
-    qreal fontsize=treeItem->getModel()->getMapDefaultFontSize();
+    qreal fontsize=font.pointSizeF();
     switch (treeItem->depth())
     {
 	case 0: 
@@ -646,7 +641,8 @@ ConvexPolygon BranchObj::getBoundingPolygon()
 {
     if (treeItem->branchCount()==0 || treeItem->depth()==0)
     {
-	if (pi) pi->setPolygon (MapObj::getBoundingPolygon() );
+	if (boundingPolygon) 
+	    boundingPolygon->setPolygon (MapObj::getBoundingPolygon() );
 	return MapObj::getBoundingPolygon();
     }
 
@@ -655,7 +651,7 @@ ConvexPolygon BranchObj::getBoundingPolygon()
     p<<bboxTotal.topRight();
     p<<bboxTotal.bottomRight();
     p<<bboxTotal.bottomLeft();
-    if (pi) pi->setPolygon (p );
+    if (boundingPolygon) boundingPolygon->setPolygon (p );
     return p;
 }
 
