@@ -16,6 +16,7 @@ extern QDir vymBaseDir;
 extern QString flagsPath;
 extern QString vymName;
 extern QString vymVersion;
+extern QString vymHome;
 extern Settings settings;
 extern QDir lastExportDir;
 
@@ -51,7 +52,7 @@ void ExportBase::init()
     outDir=lastExportDir;
 }
 
-void ExportBase::setDir(const QDir &d)
+void ExportBase::setDirectory (const QDir &d)
 {
     outDir=d;
 }
@@ -83,18 +84,16 @@ void ExportBase::addFilter(const QString &s)
 
 bool ExportBase::execDialog(const QString &overwriteWarning)
 {
-    QFileDialog fd;
-    fd.setFilter (filter);
-    fd.setWindowTitle (caption);
-    fd.setDirectory (outDir);
-    fd.setFileMode( QFileDialog::AnyFile );
-    fd.setAcceptMode (QFileDialog::AcceptSave);
-    fd.setConfirmOverwrite (false);
+    QString fn=QFileDialog::getSaveFileName( 
+	NULL,
+	caption,
+	outDir.path(), 
+	filter,
+	NULL,
+	QFileDialog::DontConfirmOverwrite);
 
-    if ( fd.exec() == QDialog::Accepted )
+    if (!fn.isEmpty() )
     {
-	if (fd.selectedFiles().isEmpty()) return false;
-	QString fn=fd.selectedFiles().first();
 	if (QFile (fn).exists() ) 
 	{
 	    WarningDialog dia;
@@ -108,7 +107,7 @@ bool ExportBase::execDialog(const QString &overwriteWarning)
 		return false;
 	    }
 	}
-	outDir=fd.directory();
+	outDir.setPath(fn.left(fn.lastIndexOf ("/")) );
 	outputFile=fn;
 	if (model) model->setChanged();
 	return true;
@@ -144,6 +143,7 @@ ExportAO::ExportAO()
 {
     filter="TXT (*.txt)";
     caption=vymName+ " -" +QObject::tr("Export as ASCII")+" "+QObject::tr("(still experimental)");
+    indentPerDepth=" ";
 }
 
 void ExportAO::doExport()   
@@ -186,13 +186,13 @@ void ExportAO::doExport()
 	    {
 		col=cur->getHeadingColor();
 		if (col==QColor (255,0,0))
-		    colString="[R]";
+		    colString="[R] ";
 		else if (col==QColor (217,81,0))
-		    colString="[O]";
+		    colString="[O] ";
 		else if (col==QColor (0,85,0))
-		    colString="[G]";
+		    colString="[G] ";
 		else	
-		    colString="";
+		    colString="  - ";
 
 		dashIndent="";	
 		switch (cur->depth())
@@ -212,20 +212,40 @@ void ExportAO::doExport()
 			ts << "\n";
 			break;
 		    case 3: // Achievement, Bonus, Objective ...
-			ts << "\n\n";
+			ts << "\n";
 			ts << underline ( cur->getHeadingPlain(), "-");
-			ts << "\n\n";
+			ts << "\n";
 			break;
 		    default:	// depth 4 are the items we need to know
 			if (cur->depth()>4) ts<<curIndent;
-			if (cur->isActiveStandardFlag ("hook-green"))
-			    ts <<colString+" "+cur->getHeadingPlain()<< " [DONE] ";
-			else	if (cur->isActiveStandardFlag ("wip"))
-			    ts <<colString+" "+cur->getHeadingPlain()<< " [WIP] ";
-			else	if (cur->isActiveStandardFlag ("cross-red"))
-			    ts <<colString+" "+cur->getHeadingPlain()<< " [NOT STARTED] ";
-			else	
-			    ts << " - " <<cur->getHeadingPlain();
+
+			Task *task=cur->getTask();
+			if (task)
+			{
+			    // Task status overrides other flags
+			    switch ( task->getStatus() )
+			    {
+				case Task::NotStarted:
+				    ts <<colString+cur->getHeadingPlain()<< " [NOT STARTED] ";
+				    break;
+				case Task::WIP:   
+				    ts <<colString+cur->getHeadingPlain()<< " [WIP] ";
+				    break;
+				case Task::Finished:
+				    ts <<colString+cur->getHeadingPlain()<< " [DONE] ";
+				    break;
+			    }
+			} else
+			{
+			    if (cur->hasActiveStandardFlag ("hook-green") )
+				ts <<colString+cur->getHeadingPlain()<< " [DONE] ";
+			    else	if (cur->hasActiveStandardFlag ("wip"))
+				ts <<colString+cur->getHeadingPlain()<< " [WIP] ";
+			    else	if (cur->hasActiveStandardFlag ("cross-red"))
+				ts <<colString+cur->getHeadingPlain()<< " [NOT STARTED] ";
+			    else	
+				ts <<"  - "+cur->getHeadingPlain();
+			}
 			ts << "\n";
 			break;
 		}
@@ -297,7 +317,7 @@ void ExportASCII::doExport()
 
 	    if (!cur->hasHiddenExportParent() )
 	    {
-		//std::cout << "ExportASCII::  "<<curIndent.toStdString()<<cur->getHeadingPlain().toStdString()<<std::endl;
+		//qDebug() << "ExportASCII::  "<<curIndent.toStdString()<<cur->getHeadingPlain().toStdString();
 
 		dashIndent="";
 		switch (cur->depth())
@@ -575,9 +595,17 @@ QString ExportHTML::getBranchText(BranchItem *current)
 	{
 	    QString n;
 	    if (current->getNoteObj().isRichText())
+	    {
 		n=current->getNote();
+		QRegExp re("<p.*>");
+		re.setMinimal (true);
+		n.replace(re,"<p class=\"vym-note-paragraph\">");
+	    }
 	    else
-		n="<pre>"+current->getNoteASCII().replace ("<","&lt;").replace (">","&gt;") +"</pre>";
+	    {
+		n=current->getNoteASCII().replace ("<","&lt;").replace (">","&gt;");
+		n.replace("\n","<br/>");
+	    }
 	    s+="\n<table class=\"vym-note\"><tr><td>\n"+n+"\n</td></tr></table>\n";
 	}   
 
@@ -727,7 +755,7 @@ void ExportHTML::doExport(bool useDialog)
 	return;
     }
     QTextStream ts( &file );	// use LANG decoding here...
-    //FIXME-3 ts.setEncoding (QTextStream::UnicodeUTF8); // Force UTF8
+    //FIXME-4 ts.setEncoding (QTextStream::UnicodeUTF8); // Force UTF8
 
     // Include image (be careful: this resets Export mode, so call before exporting branches)
     if (dia.useImage)
@@ -742,6 +770,9 @@ void ExportHTML::doExport(bool useDialog)
     // Write header
     ts<<"<html>";
     ts<<"<meta http-equiv=\"content-type\" content=\"text/html; charset=UTF-8\"> ";
+    ts<<"<meta name=\"generator=\" content=\" vym - view your mind - " + vymHome + "\">"; 
+    ts<<"<meta name=\"author\" content=\"" + model->getAuthor() + "\"> ";
+    ts<<"<meta name=\"description\" content=\"" + model->getComment() + "\"> ";
     ts<<"<title>"+model->getMapName()<<"</title><body>";
     ts<<" <link rel='stylesheet' id='css.stylesheet' href='"<<cssFileName<<"' />\n";
 
@@ -768,7 +799,7 @@ void ExportHTML::doExport(bool useDialog)
       <tr> \n\
         <td class=\"vym-footerL\">"+model->getFileName()+"</td> \n\
         <td class=\"vym-footerC\">"+model->getDate()+"</td> \n\
-        <td class=\"vym-footerR\"> vym "+vymVersion+"</td> \n\
+        <td class=\"vym-footerR\"> <a href='" + vymHome + "'>vym "+vymVersion+"</a></td> \n\
       </tr> \n \
     </table>\n";
     ts<<"</body></html>";
@@ -803,7 +834,80 @@ void ExportTaskjuggler::doExport()
 }
 
 ////////////////////////////////////////////////////////////////////////
-void ExportLaTeX::doExport() 
+void ExportOrgMode::doExport() 
+{
+    // Exports a map to an org-mode file.  
+    // This file needs to be read 
+    // by EMACS into an org mode buffer
+    QFile file (outputFile);
+    if ( !file.open( QIODevice::WriteOnly ) ) 
+    {
+	QMessageBox::critical (0,QObject::tr("Critical Export Error"),QObject::tr("Could not write %1").arg(outputFile));
+	mainWindow->statusMessage(QString(QObject::tr("Export failed.")));
+	return;
+    }
+    QTextStream ts( &file );  // use LANG decoding here...
+    //FIXME-4 ts.setEncoding (QTextStream::UnicodeUTF8); // Force UTF8
+
+    // Main loop over all branches
+    QString s;
+    int i;
+    BranchItem *cur=NULL;
+    BranchItem *prev=NULL;
+    model->nextBranch(cur,prev);
+    while (cur) 
+    {
+	if (!cur->hasHiddenExportParent() )
+	{
+	    for(i=0;i<=cur->depth();i++)
+		ts << ("*");
+	    ts << (" " + cur->getHeadingPlain()+ "\n");
+	    // If necessary, write note
+	    if (!cur->getNoteObj().isEmpty()) 
+	    {
+		ts << (cur->getNoteASCII());
+		ts << ("\n");
+	    }
+	}
+	cur=model->nextBranch(cur,prev);
+    }
+    file.close();
+}
+
+////////////////////////////////////////////////////////////////////////
+ExportLaTeX::ExportLaTeX()
+{
+    // Note: key in hash on left side is the regular expression, which 
+    // will be replaced by string on right side
+    // E.g. a literal $ will be replaced by \$
+    esc["\\$"]="\\$";
+    esc["\\^"]="\\^";
+    esc["%"]="\\%";
+    esc["&"]="\\&";
+    esc["~"]="\\~";
+    esc["_"]="\\_";
+    esc["\\\\"]="\\";
+    esc["\\{"]="\\{";
+    esc["\\}"]="\\}";
+}
+
+QString ExportLaTeX::escapeLaTeX(const QString &s)
+{
+    QString r=s;
+
+    QRegExp rx;
+    rx.setMinimal(true);
+
+    foreach (QString p,esc.keys() )
+    {
+	qDebug()<<"Replacing "<<p<<" with "<<esc[p];
+	rx.setPattern (p);
+	r.replace (rx, esc[p] );
+    }	
+    return r;
+}
+
+void ExportLaTeX::doExport()	
 {
     // Exports a map to a LaTex file.  
     // This file needs to be included 
@@ -812,55 +916,66 @@ void ExportLaTeX::doExport()
     // that makes a full LaTex document.
   QFile file (outputFile);
   if ( !file.open( QIODevice::WriteOnly ) ) {
-    QMessageBox::critical (0,QObject::tr("Critical Export Error"),QObject::tr("Could not write %1").arg(outputFile));
-    mainWindow->statusMessage(QString(QObject::tr("Export failed.")));
+    QMessageBox::critical (
+	0,
+	QObject::tr("Critical Export Error"),
+	QObject::tr("Could not write %1").arg(outputFile));
+	mainWindow->statusMessage(QString(QObject::tr("Export failed.")));
     return;
   }
   QTextStream ts( &file );  // use LANG decoding here...
-  //FIXME-3 ts.setEncoding (QTextStream::UnicodeUTF8); // Force UTF8
+  //FIXME-4 ts.setEncoding (QTextStream::UnicodeUTF8); // Force UTF8
   
+  // Read default section names
+  QStringList sectionNames;
+  sectionNames << ""
+      << "chapter"
+      << "section"
+      << "subsection"
+      << "subsubsection"
+      << "paragraph";
+
+  for (int i=0; i<6; i++)
+    sectionNames.replace(i,settings.value(
+	QString("/export/latex/sectionName-%1").arg(i),sectionNames.at(i)).toString() );
+
   // Main loop over all branches
   QString s;
-  // QString curIndent("");
-  // int i;
-  BranchObj *bo;
   BranchItem *cur=NULL;
   BranchItem *prev=NULL;
   model->nextBranch(cur,prev);
   while (cur) 
   {
-    bo=(BranchObj*)(cur->getLMO());
-
     if (!cur->hasHiddenExportParent() )
     {
-	switch (cur->depth() ) 
-	{
-	    case 0: break;
-	    case 1: 
-	      ts << ("\\chapter{" + cur->getHeadingPlain()+ "}\n");
-	      break;
-	    case 2: 
-	      ts << ("\\section{" + cur->getHeadingPlain()+ "}\n");
-	      break;
-	    case 3: 
-	      ts << ("\\subsection{" + cur->getHeadingPlain()+ "}\n");
-	      break;
-	    case 4: 
-	      ts << ("\\subsubsection{" + cur->getHeadingPlain()+ "}\n");
-	      break;
-	    default:
-	      ts << ("\\paragraph*{" + cur->getHeadingPlain()+ "}\n");
-	    
-	}
+	int d=cur->depth();
+	s=escapeLaTeX (cur->getHeadingPlain() );
+	if ( sectionNames.at(d).isEmpty() || d>=sectionNames.count() )
+	    ts << s << endl;
+	else    
+	    ts << endl
+	       << "\\" 
+	       << sectionNames.at(d) 
+	       << "{"
+	       << s
+	       << "}"
+	       << endl;
+
 	// If necessary, write note
 	if (!cur->getNoteObj().isEmpty()) {
 	  ts << (cur->getNoteASCII());
-	  ts << ("\n");
+	  ts << endl;
 	}
     }
     cur=model->nextBranch(cur,prev);
    }
-  file.close();
+    
+    file.close();
+    QString cmd="exportLaTeX";
+    settings.setLocalValue ( model->getFilePath(), "/export/last/exportPath",outputFile);
+    settings.setLocalValue ( model->getFilePath(), "/export/last/command",cmd);
+    settings.setLocalValue ( model->getFilePath(), "/export/last/description","LaTeX");
+    mainWindow->statusMessage(cmd + ": " + outputFile);
 }
 
 ////////////////////////////////////////////////////////////////////////
@@ -995,6 +1110,13 @@ void ExportOO::exportPresentation()
 
     // zip tmpdir to destination
     zipDir (tmpDir,outputFile);	
+
+    QString cmd="exportImpres";
+    settings.setLocalValue (model->getFilePath(),"/export/last/exportPath",outputFile);
+    settings.setLocalValue ( model->getFilePath(), "/export/last/command","exportImpress");
+    settings.setLocalValue ( model->getFilePath(), "/export/last/configFile",configFile);
+    settings.setLocalValue ( model->getFilePath(), "/export/last/description","OpenOffice.org Impress");
+    mainWindow->statusMessage(cmd + ": " + outputFile);
 }
 
 bool ExportOO::setConfigFile (const QString &cf)
