@@ -6,6 +6,9 @@
 
 enum ErrorLevel {NoError,Warning,Aborted};
 
+class Command;
+class TreeItem;
+
 class Parser
 {
 public:
@@ -20,7 +23,7 @@ public:
     ErrorLevel errorLevel();
     void setError (ErrorLevel level,const QString &description);
     void resetError();
-    bool checkParCount (QList <int> plist);
+    bool checkParameters(TreeItem *selti);
     bool checkParCount (const int &index);
     bool checkParIsInt (const int &index);
     bool checkParIsDouble (const int &index);
@@ -32,9 +35,10 @@ public:
 
     void setScript (const QString &);
     QString getScript();
-    void runScript();
+    void execute();
     bool next();
 
+    QStringList getCommands(); 
 
 private:
     void initParser();
