@@ -21,13 +21,12 @@ extern bool debug;
 ///////////////////////////////////////////////////////////////////////
 
 
-TextEditor::TextEditor()    
+TextEditor::TextEditor()  
 {
     statusBar()->hide();    // Hide sizeGrip on default, which comes with statusBar
 
     e = new QTextEdit( this);
     e->setFocus();
-//  e->setTextFormat(Qt::RichText);	// default
     e->setTabStopWidth (20);		// unit is pixel
     e->setTextColor (Qt::black);
     e->setAutoFillBackground (true);
@@ -40,7 +39,6 @@ TextEditor::TextEditor()
     connect(e, SIGNAL(currentCharFormatChanged(const QTextCharFormat &)),
             this, SLOT(formatChanged(const QTextCharFormat &)));
 
-
     // Don't show menubar per default
     menuBar()->hide();
 
@@ -54,22 +52,46 @@ TextEditor::TextEditor()
     blockChangedSignal=false;
     setInactive();
 
-    // Load Settings
-    /*
-    resize (settings.value ( "/satellite/noteeditor/geometry/size", QSize(450,600)).toSize());
-    move   (settings.value ( "/satellite/noteeditor/geometry/pos", QPoint (250,50)).toPoint());
-    
-    setShowWithMain (settings.value ( "/satellite/noteeditor/showWithMain",true).toBool());
+}
 
-    varFont.fromString( settings.value
-	("/satellite/noteeditor/fonts/varFont",
-	"Nimbus Sans l,10,-1,5,48,0,0,0,0,0").toString() 
-    );
+
+TextEditor::~TextEditor()
+{
+    // Save Settings
+    QString n=QString("/satellite/%1/").arg(editorName);
+    restoreState (settings.value(n+"/state",0).toByteArray());
+    settings.setValue(n+"geometry/size", size() );
+    settings.setValue(n+"geometry/pos", pos() );
+    settings.setValue(n+"state",saveState(0));
+
+    QString s;
+    if (actionSettingsFonthintDefault->isChecked() )
+	s="fixed";
+    else    
+	s="variable";
+    settings.setValue(n+"fonts/fonthintDefault",s );
+    settings.setValue(n+"fonts/varFont", varFont.toString() );
+    settings.setValue(n+"fonts/fixedFont", fixedFont.toString() );
+}
+
+void TextEditor::init (const QString &ename)
+{   
+    editorName=ename;
+    QString n=QString("/satellite/%1/").arg(editorName);
+    /*
+    restoreState (settings.value(n+"state",0).toByteArray());
+    resize (settings.value (n+"geometry/size", QSize(450,600)).toSize());
+    move   (settings.value (n+"geometry/pos", QPoint (250,50)).toPoint());
+    
+*/
+    filenameHint="";
     fixedFont.fromString (settings.value(
-	"/satellite/noteeditor/fonts/fixedFont",
-	"Courier,10-1,5,48,0,0,0,1,0").toString() 
+	n+"fonts/fixedFont", "Courier,12,-1,5,48,0,0,0,1,0").toString() 
     );
-    QString s=settings.value ("/satellite/noteeditor/fonts/fonthintDefault","variable").toString();
+    varFont.fromString( settings.value(
+	n+"fonts/varFont", "DejaVu Sans Mono,12,-1,0,50,0,0,0,0,0").toString() 
+    );
+    QString s=settings.value (n+"fonts/fonthintDefault","variable").toString();
     if (s == "fixed")
     {	
 	actionSettingsFonthintDefault->setChecked (true);
@@ -79,44 +101,11 @@ TextEditor::TextEditor()
 	actionSettingsFonthintDefault->setChecked (false);
 	e->setCurrentFont (varFont);
     }	
-    */
-    filenameHint="";
-
-    // Restore position of toolbars
-    //restoreState (settings.value("/satellite/noteeditor/state",0).toByteArray());
-
-    // Save settings in vymrc
-    //settings.setValue("/mainwindow/printerName",printer->printerName());
-}
-
-
-TextEditor::~TextEditor()
-{
-// FIXME-3    if (printer) delete printer;
 }
 
 void TextEditor::reset()
 {
     e->clear();
-    actionFormatUseFixedFont->setChecked (false);
-    actionTextBold->setChecked (false);
-    e->setFontWeight(QFont::Normal);
-
-    actionTextUnderline->setChecked (false);
-    e->setFontUnderline (false);
-
-    actionTextItalic->setChecked (false);
-    e->setFontItalic (false);
-
-    QPixmap pix( 16, 16 );
-    pix.fill( Qt::black );
-    actionTextColor->setIcon( pix );
-    e->setTextColor (Qt::black);
-
-    actionAlignSubScript->setChecked (false);
-    actionAlignSuperScript->setChecked (false);
-    actionAlignLeft->setChecked (true);
-    e->setAlignment( Qt::AlignLeft );
 }
 
 bool TextEditor::isEmpty()
@@ -127,26 +116,34 @@ bool TextEditor::isEmpty()
 	return true;
 }
 
-void TextEditor::setShowWithMain(bool v)
+void TextEditor::setFont (const QFont &font)
 {
-    showwithmain=v;
-}
+    QTextCursor tc=e->textCursor();
+    QTextCharFormat format=tc.charFormat();
 
-bool TextEditor::showWithMain()
-{
-    return showwithmain;
+    tc.select(QTextCursor::Document);
+    format.setFont (font);
+    tc.setCharFormat (format);
+    tc.clearSelection();
+    fontChanged(fixedFont);
 }
 
-
 void TextEditor::setFontHint (const QString &fh)
 {
     if (fh=="fixed")
+    {
 	actionFormatUseFixedFont->setChecked (true);
+	e->setCurrentFont (fixedFont);
+	setFont (fixedFont);
+    }	
     else
+    {
 	actionFormatUseFixedFont->setChecked (false);
+	e->setCurrentFont (varFont);
+	setFont (varFont);
+    }	
 }
 
-
 QString TextEditor::getFontHint()
 {
     if (actionFormatUseFixedFont->isChecked())
@@ -206,6 +203,14 @@ QString TextEditor::getText()
 	    return e->toPlainText();
     }
 
+NoteObj TextEditor::getNote()
+{
+    NoteObj n;
+    n.setNote (getText() );
+    n.setFontHint ( getFontHint() );
+    return n;
+}
+
 bool TextEditor::findText(const QString &t, const QTextDocument::FindFlags &flags)
 {
     if (e->find (t,flags))
@@ -345,8 +350,8 @@ void TextEditor::setupEditActions()
 
 void TextEditor::setupFormatActions()
 {
-    QToolBar *tb = addToolBar ( tr("Format Actions" ));
-    tb->setObjectName ("noteEditorFormatActions");
+    QToolBar *fontHintsToolBar = addToolBar ( tr("Font hints","toolbar in texteditor" ));
+    fontHintsToolBar->setObjectName ("noteEditorFontToolBar");
     QMenu *formatMenu = menuBar()->addMenu ( tr( "F&ormat" ));
 
     QAction *a;
@@ -357,31 +362,34 @@ void TextEditor::setupFormatActions()
     a->setChecked (settings.value("/noteeditor/fonts/useFixedByDefault",false).toBool() );
     connect( a, SIGNAL( activated() ), this, SLOT( toggleFonthint() ) );
     formatMenu->addAction (a);
-    tb->addAction (a);
+    fontHintsToolBar->addAction (a);
     actionFormatUseFixedFont=a;
 
-    a = new QAction( QPixmap(), tr( "&Richtext" ), this );
+    // Original icon: ./share/icons/oxygen/22x22/actions/format-text-color.png
+    a = new QAction( QPixmap(iconPath+"formatrichtext.png"), tr( "&Richtext" ), this ); 
     a->setShortcut (Qt::ALT + Qt::Key_R);
     a->setCheckable (true);
-    //a->setChecked (settings.value("/noteeditor/fonts/useFixedByDefault",false).toBool() );
     connect( a, SIGNAL( activated() ), this, SLOT( toggleRichText() ) );
     formatMenu->addAction (a);
-    tb->addAction (a);
+    fontHintsToolBar->addAction (a);
     actionFormatRichText=a;
 
+    QToolBar *fontToolBar = addToolBar ( tr("Fonts","toolbar in texteditor" ));
+    fontToolBar->setObjectName ("noteEditorFontToolBar");
+
     comboFont = new QComboBox;
-    tb->addWidget (comboFont);
+    fontToolBar->addWidget (comboFont);
     QFontDatabase fontDB;
     comboFont->insertItems ( 0,fontDB.families() );
     connect( comboFont, SIGNAL( activated( const QString & ) ),
 	 this, SLOT( textFamily( const QString & ) ) );
 
     comboSize = new QComboBox;
-    tb->addWidget (comboSize);
+    fontToolBar->addWidget (comboSize);
     QList<int> sizes=fontDB.standardSizes();
     QList<int>::iterator it = sizes.begin();
     int i=0;
-    while (it != sizes.end()) //FIXME-3 check and make better...
+    while (it != sizes.end()) 
     {
 	i++;
 	++it; // increment i before using it
@@ -392,18 +400,21 @@ void TextEditor::setupFormatActions()
 
     formatMenu->addSeparator();
 
+    QToolBar *formatToolBar = addToolBar ( tr("Format","toolbar in texteditor" ));
+    formatToolBar->setObjectName ("noteEditorFormatToolBar");
+
     QPixmap pix( 16, 16 );
     pix.fill( e->textColor());
     a = new QAction( pix, tr( "&Color..." ), this);
     formatMenu->addAction (a);
-    tb->addAction (a);
+    formatToolBar->addAction (a);
     connect( a, SIGNAL( activated() ), this, SLOT( textColor() ) );
     actionTextColor=a;
 
     a = new QAction( QPixmap (iconPath+"text_bold.png"), tr( "&Bold" ), this);
     a->setShortcut(Qt::CTRL + Qt::Key_B );
     connect( a, SIGNAL( activated() ), this, SLOT( textBold() ) );
-    tb->addAction (a);
+    formatToolBar->addAction (a);
     formatMenu->addAction (a);
     a->setCheckable( true );
     actionTextBold=a;
@@ -411,7 +422,7 @@ void TextEditor::setupFormatActions()
     a = new QAction( QPixmap(iconPath+"text_italic.png"), tr( "&Italic" ),  this);
     a->setShortcut(Qt::CTRL + Qt::Key_I);
     connect( a, SIGNAL( activated() ), this, SLOT( textItalic() ) );
-    tb->addAction (a);
+    formatToolBar->addAction (a);
     formatMenu->addAction (a);
     a->setCheckable( true );
     actionTextItalic=a;
@@ -419,7 +430,7 @@ void TextEditor::setupFormatActions()
     a = new QAction( QPixmap (iconPath+"text_under.png"), tr( "&Underline" ), this);
     a->setShortcut(Qt::CTRL + Qt::Key_U );
     connect( a, SIGNAL( activated() ), this, SLOT( textUnderline() ) );
-    tb->addAction (a);
+    formatToolBar->addAction (a);
     formatMenu->addAction (a);
     a->setCheckable( true );
     //richTextWidgets.append((QWidget*)a);
@@ -431,7 +442,7 @@ void TextEditor::setupFormatActions()
     a = new QAction( QPixmap (iconPath+"text_sub.png"), tr( "Subs&cript" ),grp2 );
     a->setShortcut( Qt::CTRL + Qt::SHIFT + Qt::Key_B );
     a->setCheckable( true );
-    tb->addAction (a);
+    formatToolBar->addAction (a);
     formatMenu->addAction (a);
     connect(a, SIGNAL(activated()), this, SLOT(textVAlign()));
     actionAlignSubScript=a;
@@ -439,7 +450,7 @@ void TextEditor::setupFormatActions()
     a = new QAction( QPixmap (iconPath+"text_super.png"), tr( "Su&perscript" ),grp2  );
     a->setShortcut( Qt::CTRL + Qt::SHIFT + Qt::Key_P );
     a->setCheckable( true );
-    tb->addAction (a);
+    formatToolBar->addAction (a);
     formatMenu->addAction (a);
     connect(a, SIGNAL(activated()), this, SLOT(textVAlign()));
     actionAlignSuperScript=a;
@@ -451,25 +462,25 @@ void TextEditor::setupFormatActions()
     a = new QAction( QPixmap (iconPath+"text_left.png"), tr( "&Left" ),grp );
     //a->setShortcut( Qt::CTRL+Qt::Key_L );
     a->setCheckable( true );
-    tb->addAction (a);
+    formatToolBar->addAction (a);
     formatMenu->addAction (a);
     actionAlignLeft=a;
     a = new QAction( QPixmap (iconPath+"text_center.png"), tr( "C&enter" ),grp);
     //a->setShortcut(  Qt::CTRL + Qt::Key_E);
     a->setCheckable( true );
-    tb->addAction (a);
+    formatToolBar->addAction (a);
     formatMenu->addAction (a);
     actionAlignCenter=a;
     a = new QAction( QPixmap (iconPath+"text_right.png" ), tr( "&Right" ), grp);
     //a->setShortcut(Qt::CTRL + Qt::Key_R );
     a->setCheckable( true );
-    tb->addAction (a);
+    formatToolBar->addAction (a);
     formatMenu->addAction (a);
     actionAlignRight=a;
     a = new QAction( QPixmap ( iconPath+"text_block.png"), tr( "&Justify" ), grp );
     //a->setShortcut(Qt::CTRL + Qt::Key_J );
     a->setCheckable( true );
-    tb->addAction (a);
+    formatToolBar->addAction (a);
     formatMenu->addAction (a);
     actionAlignJustify=a;
 }
@@ -545,7 +556,6 @@ void TextEditor::textLoad()
 void TextEditor::closeEvent( QCloseEvent* ce )
 {
     ce->accept();   // TextEditor can be reopened with show()
-    showwithmain=false;
     hide();
     emit (windowClosed() );
     return;
@@ -601,10 +611,16 @@ void TextEditor::editCopyAll()
     e->copy();
 }
 
-void TextEditor::textSaveAs()	//FIXME-3 Use WarningDialog
+void TextEditor::textSaveAs()	
 {
     QString caption=tr ("Export Note to single file");
-    QString fn = QFileDialog::getSaveFileName(this, caption, QString::null, "VYM Note (HTML) (*.html);;All files (*)",0,QFileDialog::DontConfirmOverwrite );
+    QString fn = QFileDialog::getSaveFileName(
+	this, 
+	caption, 
+	QString::null, 
+	"VYM Note (HTML) (*.html);;All files (*)",
+	0,
+	QFileDialog::DontConfirmOverwrite );
 
     if ( !fn.isEmpty() ) 
     {
@@ -648,7 +664,7 @@ void TextEditor::textSave()
 	return;
     }
 
-    QString text = e->toHtml(); //FIXME-3 or plaintext? check...
+    QString text = e->toHtml(); //FIXME-4 or plaintext? check...
     QFile f( filename );
     if ( !f.open( QIODevice::WriteOnly ) ) 
     {
@@ -734,45 +750,45 @@ void TextEditor::textEditUndo()
 
 void TextEditor::toggleFonthint()
 {
-    setUpdatesEnabled (false);
-    e->selectAll ();
     if (!actionFormatUseFixedFont->isChecked() ) 
+    {
 	e->setCurrentFont (varFont);
+	setFont (varFont);
+    }	
     else    
+    {
 	e->setCurrentFont (fixedFont);
-    e->selectAll ();
-    setUpdatesEnabled (true);
-    repaint();
+	setFont (fixedFont);
+    }	
 }
 
 void TextEditor::toggleRichText()
 {
-    //setUpdatesEnabled (false);
     if (!actionFormatRichText->isChecked() ) 
+    {
 	e->setPlainText (e->toPlainText());
+	actionFormatUseFixedFont->setEnabled(true);
+    }
     else    
+    {
 	e->setHtml (e->toHtml());
+	actionFormatUseFixedFont->setEnabled(false);
+    }
     updateActions();	
 }
 
 void TextEditor::setFixedFont()
 {
     bool ok;
-    QFont font =QFontDialog::getFont(
-                    &ok, fixedFont, this );
-    if ( ok ) 
-        // font is set to the font the user selected
-	fixedFont=font;
+    QFont font =QFontDialog::getFont( &ok, fixedFont, this );
+    if ( ok ) fixedFont=font;
 }
 
 void TextEditor::setVarFont()
 {
     bool ok;
-    QFont font =QFontDialog::getFont(
-                    &ok, varFont, this );
-    if ( ok ) 
-        // font is set to the font the user selected
-	varFont=font;
+    QFont font =QFontDialog::getFont( &ok, varFont, this );
+    if ( ok ) varFont=font;
 }
 
 void TextEditor::textBold()
@@ -814,7 +830,7 @@ void TextEditor::textColor()
     actionTextColor->setIcon( pix );
 }
 
-void TextEditor::textAlign( QAction *a )
+void TextEditor::textAlign( QAction *a )  //FIXME-2 center only centers first line
 {
     QTextCursor c=e->textCursor();
     c.setPosition (3,QTextCursor::MoveAnchor);
@@ -865,6 +881,7 @@ void TextEditor::colorChanged( const QColor &c )
 
 void TextEditor::formatChanged( const QTextCharFormat &f )
 {
+    if (!actionFormatRichText->isChecked() ) return;
     fontChanged(f.font());
     colorChanged(f.foreground().color());
     alignmentChanged(e->alignment());
@@ -950,11 +967,10 @@ void TextEditor::updateActions()
 	actionAlignCenter->setEnabled(true);
 	actionAlignRight->setEnabled(true);
 	actionAlignJustify->setEnabled(true);
+	actionFormatUseFixedFont->setEnabled(false);
     }
 }
 
-
-
 void TextEditor::setState (EditorState s)
 {
     
