@@ -11,13 +11,13 @@
 
 using namespace std;
 
+extern uint itemLastID;
 extern FlagRow* standardFlagsMaster;
-
-uint TreeItem::idLast=0;    // Create instance
+extern FlagRow* systemFlagsMaster;
 
 TreeItem::TreeItem()
 {
-    //cout << "Constr. TI  this="<<this<<endl;
+    //qDebug() << "Constr. TI  this="<<this;
     init();
     itemData.clear();
     rootItem=this;
@@ -26,7 +26,7 @@ TreeItem::TreeItem()
 
 TreeItem::TreeItem(const QList<QVariant> &data, TreeItem *parent)
 {
-    //cout << "Constructor TreeItem this="<<this<<"  parent="<<parent<<endl;
+    //qDebug() << "Constructor TreeItem this="<<this<<"  parent="<<parent;
     init();
     parentItem = parent;
     itemData = data;
@@ -39,20 +39,10 @@ TreeItem::TreeItem(const QList<QVariant> &data, TreeItem *parent)
 TreeItem::~TreeItem()
 {
     //qDebug()<<"Destr TreeItem this="<<this<<"  childcount="<<childItems.count();
-    /*
-    qDeleteAll(childItems); // Call delete  //FIXME-3 use this instead of below
-    qDebug()<<"  ok1";
-    childItems.clear();	    // and clear list
-    qDebug()<<"  ok2";use
-    */
-
-    //qDebug()<<"                   ="<<getHeading();
     TreeItem *ti;
     while (!childItems.isEmpty())
     {
-	//qDebug()<<"    ="<<ti->getHeading();
 	ti=childItems.takeFirst();
-	//qDebug()<<"  ti="<<ti;
 	delete ti;
     }
 }
@@ -63,8 +53,9 @@ void TreeItem::init()
     model=NULL;
 
     // Assign ID  
-    idLast++;
-    id=idLast;
+    itemLastID++;
+    id=itemLastID;
+    uuid=QUuid::createUuid();
 
     branchOffset=0;
     branchCounter=0;
@@ -81,8 +72,6 @@ void TreeItem::init()
     target=false;
 
     note.setNote(""); 
-    // note.setFontHint (textEditor->getFontHintDefault() );	//FIXME-3
-    // isNoteInEditor=false;
 
     hidden=false;
     hideExport=false;
@@ -91,9 +80,9 @@ void TreeItem::init()
     backgroundColor=Qt::transparent;
 
     standardFlags.setMasterRow (standardFlagsMaster);
+    systemFlags.setMasterRow (systemFlagsMaster);
 }
 
-
 void TreeItem::setModel (VymModel *m)
 {
     model=m;
@@ -154,7 +143,7 @@ void TreeItem::appendChild(TreeItem *item)
 	childItems.append(item);
 	branchCounter++;
 
-	// Set correct type	//FIXME-3 DUP in constr branchitem
+	// Set correct type	//FIXME-5 DUP in constr branchitem
 	if (this==rootItem)
 	    item->setType(MapCenter);
 	else
@@ -165,7 +154,7 @@ void TreeItem::appendChild(TreeItem *item)
 void TreeItem::removeChild(int row)
 {
     if (row<0 || row > childItems.size()-1)
-	qWarning ("TreeItem::removeChild tried to remove non existing item?!\n");
+	qWarning ("TreeItem::removeChild tried to remove non existing item?!");
     else
     {
 	if (childItems.at(row)->type==Attribute)
@@ -241,7 +230,7 @@ int TreeItem::row() const
     if (parentItem)
         return parentItem->childItems.indexOf(const_cast<TreeItem*>(this));
 
-    cout << "TI::row() pI=NULL this="<<this<<"  ***************\n";
+    qDebug() << "TI::row() pI=NULL this="<<this<<"  ***************";
     return 0;
 }
 
@@ -261,7 +250,7 @@ int TreeItem::depth()
 
 TreeItem *TreeItem::parent()
 {
-    //cout << "TI::parent of "<<getHeadingStd()<<"  is "<<parentItem<<endl;
+    //qDebug() << "TI::parent of "<<getHeadingStd()<<"  is "<<parentItem;
     return parentItem;
 }
 
@@ -298,7 +287,7 @@ void TreeItem::setType(const Type t)
 
 TreeItem::Type TreeItem::getType()
 {
-    if (type==Branch && depth()==0) return MapCenter;	//FIXME-3 should not be necesssary
+    if (type==Branch && depth()==0) return MapCenter;	//FIXME-5 should not be necesssary
     return type;
 }
 
@@ -345,7 +334,7 @@ std::string TreeItem::getHeadingStd () const
 }
 
 #include "noteobj.h"
-QString TreeItem::getHeadingPlain() const   //FIXME-3 create own TextObj instead of recreating from ASCII note every time
+QString TreeItem::getHeadingPlain() const   //FIXME-4 create own TextObj instead of recreating from ASCII note every time
 {
     NoteObj no(itemData[0].toString());
     QString t=no.getNoteASCII();
@@ -441,7 +430,7 @@ void TreeItem::toggleTarget ()
 {
     systemFlags.toggle ("system-target");
     target= systemFlags.isActive("system-target");
-    model->emitDataHasChanged(this);	// FIXME-3 better call from VM?
+    model->emitDataChanged(this);	// FIXME-4 better call from VM?
 }
 
 bool TreeItem::isTarget ()
@@ -503,39 +492,38 @@ QString TreeItem::getNoteOpenDoc()
 void TreeItem::activateStandardFlag (const QString &name)
 {
     standardFlags.activate (name);
-    model->emitDataHasChanged(this);
+    model->emitDataChanged(this);
 }
 
 void TreeItem::deactivateStandardFlag (const QString &name)
 {
     standardFlags.deactivate (name);
-    model->emitDataHasChanged(this);
+    model->emitDataChanged(this);
 }
 
 void TreeItem::deactivateAllStandardFlags ()
 {
     standardFlags.deactivateAll ();
-    model->emitDataHasChanged(this);
+    model->emitDataChanged(this);
 }
 
 void TreeItem::toggleStandardFlag(const QString &name, FlagRow *master)
 {
     standardFlags.toggle (name,master);
-    model->emitDataHasChanged(this);	// FIXME-3 better call from VM?
 }
 
 void TreeItem::toggleSystemFlag(const QString &name, FlagRow *master)
 {
     systemFlags.toggle (name,master);
-    model->emitDataHasChanged(this);	// FIXME-3 better call from VM?
+    model->emitDataChanged(this);
 }
 
-bool TreeItem::isActiveStandardFlag (const QString &name)
+bool TreeItem::hasActiveStandardFlag (const QString &name)
 {
     return standardFlags.isActive (name);
 }
 
-bool TreeItem::isActiveSystemFlag (const QString &name)
+bool TreeItem::hasActiveSystemFlag (const QString &name)
 {
     return systemFlags.isActive (name);
 }
@@ -594,6 +582,16 @@ uint TreeItem::getID()
     return id;
 }
 
+void TreeItem::setUuid(const QString &id)
+{
+    uuid=QUuid(id);
+}
+
+QUuid TreeItem::getUuid()
+{
+    return uuid;
+}
+
 TreeItem* TreeItem::getChildNum(const int &n)
 {
     if (n>=0 && n<childItems.count() )
@@ -718,14 +716,14 @@ XLinkObj* TreeItem::getXLinkObjNum (const int &n)
 }
 
 
-void TreeItem::setHideTmp (HideTmpMode mode)  //FIXME-3	update visibility in derived objects
+void TreeItem::setHideTmp (HideTmpMode mode) 
 {
     if (type==Image || type==Branch || type==MapCenter)
 //	((ImageItem*)this)->updateVisibility();
     {
 	//LinkableMapObj* lmo=((MapItem*)this)->getLMO();
 
-	if (mode==HideExport && (hideExport || hasHiddenExportParent() ) ) // FIXME-3  try to avoid calling hasScrolledParent repeatedly
+	if (mode==HideExport && (hideExport || hasHiddenExportParent() ) ) // FIXME-4  try to avoid calling hasScrolledParent repeatedly
 
 	    // Hide stuff according to hideExport flag and parents
 	    hidden=true;
