@@ -2,6 +2,7 @@
 #define TREEITEM_H
 
 #include <QColor>
+#include <QUuid>
 #include <QList>
 #include <QVariant>
 
@@ -30,6 +31,7 @@ public:
     TreeItem(const QList<QVariant> &data, TreeItem *parent = 0);
     virtual ~TreeItem();
     void init();
+    virtual void clear()=0;
 
     // General housekeeping
     virtual void setModel (VymModel *m);
@@ -136,8 +138,8 @@ public:
     */	
     virtual void toggleStandardFlag(const QString &flag, FlagRow *master=NULL);
     virtual void toggleSystemFlag  (const QString &flag, FlagRow *master=NULL);
-    virtual bool isActiveStandardFlag (const QString &flag);
-    virtual bool isActiveSystemFlag   (const QString &flag);
+    virtual bool hasActiveStandardFlag (const QString &flag);
+    virtual bool hasActiveSystemFlag   (const QString &flag);
     virtual QStringList activeStandardFlagNames();
     virtual FlagRow* getStandardFlagRow ();
 
@@ -147,10 +149,13 @@ public:
     virtual bool canMoveUp();
 
 protected:
-    static uint idLast;		// the last used unique ID
     uint id;
+    QUuid uuid;
+
 public:
     virtual uint getID ();
+    virtual void setUuid (const QString &id);
+    virtual QUuid getUuid();
 
     // Navigation and selection
     virtual TreeItem* getChildNum(const int &n);
