@@ -3,9 +3,6 @@
 
 #include <QtNetwork>
 
-#include <QtDBus/QDBusAbstractAdaptor>
-#include <QtDBus/QDBusVariant>
-
 #include <QPointF>
 #include <QTextCursor>
 
@@ -20,9 +17,13 @@
 class AttributeItem;
 class BranchItem;
 class FindResultModel;
-class MapEditor;
 class Link;
+class MapEditor;
+class SlideItem;
+class SlideModel;
+class Task;
 class XLinkItem;
+class VymView;
 
 class QGraphicsScene;
 
@@ -42,7 +43,7 @@ private:
     QDate date;
 
     static uint idLast;	    //! the last used unique ID
-    uint mapID;
+    uint modelID;
 
 public:
     VymModel();
@@ -52,8 +53,13 @@ public:
     void makeTmpDirectories();	    //!< create temporary directories e.g. for history
 
     MapEditor* getMapEditor();		
-    uint getID();			//! Return unique ID of model
+    uint getModelID();			//! Return unique ID of model
 
+    void setView (VymView*);	    //! Set vymView for resizing editors after load
+private:
+    VymView *vymView;
+
+public:
     bool isRepositionBlocked();	    //!< While load or undo there is no need to update graphicsview
 
     void updateActions();	    //!< Update buttons in mainwindow
@@ -68,10 +74,19 @@ private:
     static  int mapNum;		// unique number for model used in save/undo
     FileType fileType;		// type of file, e.g. vym, freemind...
     QString fileName;		// short name of file (for tab)
+				// example.vym
+
     QString filePath;		// path to file which will be saved
+				// /home/tux/example.vym
+
     QString fileDir;		// dir where file is saved
+				// /home/tux/
+
     QString destPath;		// path to .vym file (needed for vymlinks)
+				// /home/tux/example.vym
+
     QString mapName;		// fileName without ".vym"
+				// example
 
     QString tmpMapDir;		// tmp directory with undo history
 
@@ -106,6 +121,7 @@ public:
     void setFilePath (QString filepath,QString destname);   
     void setFilePath (QString);	//!< Overloaded for convenience
     QString getFilePath (); //!< Full path e.g. "/home/tux/map.xml"
+    QString getFileDir ();  //!< e.g. "/home/tux"
     QString getFileName (); //!< e.g. "map.xml"
     QString getMapName ();  //!< e.g. "map"
     QString getDestPath (); //!< e.g. "/home/tux/map.vym"
@@ -115,24 +131,21 @@ public:
 	The data is read from file. Depending on LoadMode the current
 	selection gets replaced by data or the data is appended.
     */	
-    ErrorCode loadMap  (
+    File::ErrorCode loadMap  (
 	QString,			//!< Path
 	const LoadMode &lmode=NewMap,	//!< New map, replace or add to selection
-	bool saveStateFlag=true,	//!< If called internally for history, don't save
 	const FileType &ftype=VymMap,	//!< VymMap or FreeMind
+	const int &contentFilter=0x0000,//!< For undo types of content can be filterd
 	int pos=-1			//!< Optionally tell position where to add data
     );	
 
 public:
     /*! \brief Save the map to file */
-    ErrorCode save(const SaveMode &);	
+    File::ErrorCode save(const SaveMode &);	
 
-private:
-    ImageItem* loadFloatImageInt (BranchItem *dst,QString);
-    bool saveFloatImageInt (ImageItem*, const QString &, const QString &);
 public:	
-    void loadFloatImage ();
-    void saveFloatImage ();
+    void loadImage (BranchItem *dst=NULL, const QString &fn="");
+    void saveImage (ImageItem *ii=NULL, QString format="", QString fn="");
 
 private:    
     void importDirInt(BranchItem *,QDir);
@@ -202,7 +215,8 @@ public:
 	const QString &redoSelection, 
 	const QString &redoCommand, 
 	const QString &comment, 
-	TreeItem *saveSelection);
+	TreeItem *saveSelection,
+	QString dataXML="");
 
     /*! Overloaded for convenience */
     void saveStateChangingPart(
@@ -247,7 +261,10 @@ public:
 	const QString &redoCommand, 
 	const QString &comment); 
 	
-
+    /*! Save state before loading a map */
+    void saveStateBeforeLoad (
+	LoadMode lmode,
+	const QString &fname);
 
 ////////////////////////////////////////////
 // unsorted so far
@@ -256,7 +273,8 @@ public:
     QGraphicsScene *getScene();
 
     TreeItem* findBySelectString (QString s);	    
-    TreeItem* findID (const uint &i);	    // find MapObj by unique ID
+    TreeItem* findID   (const uint &i);	    // find MapObj by unique ID
+    TreeItem* findUuid (const QUuid &i);    // find MapObj by unique ID
 
 
 ////////////////////////////////////////////
@@ -301,13 +319,14 @@ private:
     QString findString;
 
 public:
-    void setURL(const QString &url);
+    void setURL(QString url);
     QString getURL();			    // returns URL of selection or ""
     QStringList getURLs(bool ignoreScrolled=true);  // returns URLs of subtree
 
 
     void setFrameType(const FrameObj::FrameType &);
     void setFrameType(const QString &);
+    void toggleFrameIncludeChildren ();
     void setFrameIncludeChildren (bool);
     void setFramePenColor (const QColor &);
     void setFrameBrushColor (const QColor &);
@@ -318,16 +337,25 @@ public:
     void setHideLinkUnselected (bool);
 
     /*! Should object be hidden in exports (clouded)? */
-    void setHideExport(bool);		
+    void setHideExport(bool, TreeItem* ti=NULL);		
 
     /*! Should object be hidden in exports (clouded)? */
     void toggleHideExport();	    
 
+    /*! Toggle task for branch */
+    void toggleTask();	    
+
+    /*! Cycle through task states */
+    void cycleTaskStatus(bool reverse=false);	    
+
+    /*! Set task to sleep for n days */
+    void setTaskSleep(int n);
+    /*! count tasks in this model */
+    int taskCount();
+
     void addTimestamp();	
 
     void copy();			//!< Copy to clipboard
-private:    
-    void pasteNoSave(const int &n);	//!< paste clipboard to branch
 public:	
     void paste();	    //!< Paste clipboard to branch and backup
     void cut();		    //!< Cut to clipboard (and copy)
@@ -346,6 +374,9 @@ public:
 
 public:	
     bool createLink(Link *l, bool createMO=false);	    //!< Create XLink 
+    QColor getXLinkColor();
+    int getXLinkWidth();
+    Qt::PenStyle getXLinkPenStyle();
 
     AttributeItem* addAttribute();
     AttributeItem* addAttribute(BranchItem *dst, AttributeItem* );
@@ -370,16 +401,17 @@ private:
     */	
 
 private:    
-    BranchItem* addNewBranchInt(BranchItem *dst, int pos);  // pos allows to add above/below selection
+    BranchItem* addNewBranchInt(BranchItem *dst, int pos);  // pos allows to add above/below selection, or as child  at pos
 public:	
     /*! \Add new branch
 	
-	Depending on num the new branch is created
-	-1 above selection
-	 0 as child of selection
-	 1 below selection
+    // Depending on pos:
+    // -3	insert in children of parent  above selection 
+    // -2	add branch to selection 
+    // -1	insert in children of parent below selection 
+    // 0..n	insert in children of parent at pos
     */
-    BranchItem* addNewBranch(int pos=0,BranchItem *bi=NULL);	
+    BranchItem* addNewBranch(BranchItem *bi=NULL, int pos=-2);	
     BranchItem* addNewBranchBefore();	    //!< Insert branch between selection and its parent
     /*! \brief Relink a branch to a new destination dst 
 	Relinks branch to dst at branch position pos. There is no saveState
@@ -463,9 +495,8 @@ public:
     QVariant parseAtom (const QString &atom, bool &noError, QString &errorMsg);	
 
     /* \brief Runs the script */
-    QVariant runScript (const QString &script);
+    QVariant execute (const QString &script);
 
-private:
     Parser parser;
 
 ////////////////////////////////////////////
@@ -500,14 +531,20 @@ public:
     void exportHTML(const QString& dir="", bool useDialog=true);    
 
     /*! Export as OpenOfficeOrg presentation */
-    void exportOOPresentation(const QString &,const QString &);	
+    void exportImpress (const QString &,const QString &);	
 
     /*! Returns if Export in recently used format is possible*/
-    bool exportLastAvailable(QString &description, QString &command, QString &path);
+    bool exportLastAvailable(
+	QString &description, 
+	QString &command, 
+	QString &configFile,
+	QString &path);
 
     /*! Export in recently used format (saved in map)*/
     void exportLast();
 
+    /*! Export as LaTeX */
+    void exportLaTeX (const QString& dir="", bool useDialog=true);    
 
 ////////////////////////////////////////////
 // View related
@@ -517,8 +554,15 @@ public:
     void unregisterEditor (QWidget *);
 
     void setMapZoomFactor (const double &); 
+    void setMapRotationAngle (const double&);
+    void setMapAnimDuration(const int &d);
+    void setMapAnimCurve(const QEasingCurve &c);
 private: 
     double zoomFactor;
+    double rotationAngle;
+    int animDuration;
+    QEasingCurve animCurve;
+
     bool hasContextPos;			//!< True, if we have a context pos
     QPointF contextPos;			//!< local position during context menu
 public:
@@ -529,30 +573,28 @@ public:
     void reposition();			//!< Call reposition for all MCOs
     void setHideTmpMode (TreeItem::HideTmpMode mode);	
 
-    void emitNoteHasChanged  (TreeItem *ti);
-    void emitDataHasChanged  (TreeItem *ti);
+    void emitNoteChanged  (TreeItem *ti);
+    void emitDataChanged  (TreeItem *ti);
     void emitUpdateQueries   ();       //!< tell MainWindow to update find results...
     void emitUpdateLayout ();
 
 signals:
     void updateQueries(VymModel *m);
     void updateLayout();
-    void noteHasChanged (QModelIndex ix);
+    void noteChanged (QModelIndex ix);
     void newChildObject(QModelIndex ix);
 
 private:
     MapEditor *mapEditor;
 
     QColor defLinkColor;	// default color for links
-    QColor defXLinkColor;	// default color for xlinks
-    int defXLinkWidth;		// default width for xlinks
+    QPen defXLinkPen;		// default pen for xlinks
     LinkableMapObj::ColorHint linkcolorhint;// use heading color or own color
     LinkableMapObj::Style linkstyle;	    // default style for links
     QFont defaultFont;
-    qreal defaultFontSize;
 
 public:
-    void setMapLinkStyle (const QString &); // Set style of link
+    bool setMapLinkStyle (const QString &); // Set style of link
     LinkableMapObj::Style getMapLinkStyle ();	// requested in LMO
     void setMapDefLinkColor(QColor);	    // default color of links
     void setMapLinkColorHintInt();	    // color of links
@@ -566,15 +608,11 @@ public:
 
     QFont getMapDefaultFont();
     void setMapDefaultFont (const QFont&);
-    qreal getMapDefaultFontSize();
-    void setMapDefaultFontSize (const qreal&);
 
     LinkableMapObj::ColorHint getMapLinkColorHint();
     QColor getMapDefLinkColor();
-    void setMapDefXLinkColor(QColor);
-    QColor getMapDefXLinkColor();
-    void setMapDefXLinkWidth (int);
-    int getMapDefXLinkWidth();
+    void setMapDefXLinkPen (const QPen &p);
+    QPen getMapDefXLinkPen();
 
     /*!  Move absolutly to (x,y).  */	
     void move    (const double &x, const double &y);
@@ -642,16 +680,6 @@ private slots:
 public:
     void download (const QUrl &url, BranchItem *bi=NULL);
 
-////////////////////////////////////////////
-// DBUS related 
-////////////////////////////////////////////
-
-private:
-AdaptorModel *adaptorModel; //FIXME-3
-
-public slots:
-    void testslot();
-
 ////////////////////////////////////////////
 // Selection related 
 ////////////////////////////////////////////
@@ -661,6 +689,9 @@ private:
     int currentSelection;
     bool keepSelectionHistory;			    // If set, selection doesn't change history
 
+public slots:
+    void updateSelection(QItemSelection ,QItemSelection); // update selection
+
 public:
     void setSelectionModel(QItemSelectionModel *);	// Set common selectionModel
     QItemSelectionModel* getSelectionModel();
@@ -668,12 +699,14 @@ public:
     void setSelectionBlocked(bool);
     bool isSelectionBlocked();
 
-    bool select ();			    //! select by using common QItemSelectionModel
     bool select (const QString &);	    //! Select by string
+    bool selectID (const QString &);	    //! select by unique ID (QUuid)
     bool select (LinkableMapObj *lmo);	    //! Select by pointer to LMO
+    bool selectToggle (TreeItem *ti);	    //! Toggle select state
     bool select (TreeItem *ti );	    //! Select by pointer to TreeItem
     bool select (const QModelIndex &index); //! Select by ModelIndex
-    void unselect();
+    void unselectAll ();
+    void unselect (QItemSelection desel);
     bool reselect();
     bool canSelectPrevious();
     bool selectPrevious();
@@ -698,16 +731,22 @@ public:
     LinkableMapObj* getSelectedLMO();
     BranchObj* getSelectedBranchObj();	
     BranchItem* getSelectedBranch();
+    QList <BranchItem*> getSelectedBranches();
     ImageItem* getSelectedImage();
+    Task *getSelectedTask();
     XLinkItem* getSelectedXLinkItem();
     Link* getSelectedXLink();
     AttributeItem* getSelectedAttribute();
     TreeItem* getSelectedItem();
+    QList <TreeItem*> getSelectedItems();
     QModelIndex getSelectedIndex();
+    QList <uint> getSelectedIDs();
+    bool isSelected(TreeItem*);
     QString getSelectString ();
     QString getSelectString (LinkableMapObj *lmo);
     QString getSelectString (TreeItem *item);
     QString getSelectString (BranchItem *item);
+    QString getSelectString (const uint &i);
     
     
 signals:
@@ -727,6 +766,25 @@ private:
 public:	
     void setSelectionColor(QColor);
     QColor getSelectionColor();
-};
 
+////////////////////////////////////////////
+// Slide related
+////////////////////////////////////////////
+public:
+    SlideModel* getSlideModel();
+    int slideCount();
+    SlideItem* addSlide ();
+    void deleteSlide (SlideItem *si);
+    void deleteSlide (int n);
+    void relinkSlide (SlideItem *si, int pos);
+    void moveSlideUp( int n=-1);
+    void moveSlideDown( int n=-1);
+    SlideItem *findSlideID (uint id);
+public slots:
+    void updateSlideSelection (QItemSelection ,QItemSelection);
+private:
+    SlideModel* slideModel;
+    bool blockSlideSelection;
+
+};
 #endif
