@@ -2,23 +2,27 @@
 #define VYMVIEW_H
 
 #include <QItemSelectionModel>
+#include <QMainWindow>
 #include <QWidget>
 
+class DockEditor;
 class VymModel;
 class MapEditor;
+class SlideEditor;
 class TreeEditor;
-
 class QTreeView;
 
-class VymView:public QWidget
+class VymView:public QMainWindow
 {
     Q_OBJECT
 public:
     VymView(VymModel *model);
     ~VymView();
+    void readSettings();
     VymModel* getModel();
     MapEditor* getMapEditor();
-    TreeEditor* getTreeEditor();
+    bool treeEditorIsVisible();
+    bool slideEditorIsVisible();
     void initFocus();
 
 public slots:
@@ -29,12 +33,18 @@ public slots:
     void collapseUnselected();
     void showSelection ();
     void toggleTreeEditor();
+    void toggleSlideEditor();
 
 private:
     VymModel *model;
     TreeEditor *treeEditor;
-    QItemSelectionModel *selModel;
+    DockEditor *treeEditorDE;
+    SlideEditor *slideEditor;
+    DockEditor  *slideEditorDE;
+
     MapEditor *mapEditor;
+    //DockEditor *mapEditorDE;
+    QItemSelectionModel *selModel;
 };
 
 
