@@ -3,7 +3,6 @@
 #include <QMessageBox>
 #include <QColor>
 #include <QTextStream>
-#include <iostream>
 #include <typeinfo>
 
 #include "attributeitem.h"
@@ -12,21 +11,35 @@
 #include "settings.h"
 #include "linkablemapobj.h"
 #include "mainwindow.h"
+#include "slideitem.h"
+#include "task.h"
+#include "taskmodel.h"
 #include "version.h"
 #include "xlinkitem.h"
 
 extern Main *mainWindow;
 extern Settings settings;
+extern TaskModel *taskModel;
 extern QString vymVersion;
 
+parseVYMHandler::parseVYMHandler()
+{
+    // Default is to load everything
+    contentFilter = 0x0000; //FIXME-4 use filters for all content types below
+}
+
+void parseVYMHandler::setContentFilter (const int &c)
+{
+    contentFilter=c;
+}
+
 bool parseVYMHandler::startDocument()
 {
     errorProt = "";
     state = StateInit;
-    laststate = StateInit;
     stateStack.clear();
     stateStack.append(StateInit);
-    textdata="";
+    htmldata="";
     isVymPart=false;
     useProgress=false;
     return true;
@@ -37,12 +50,12 @@ bool parseVYMHandler::startElement  ( const QString&, const QString&,
 {
     QColor col;
     /* Testing
-    cout << "startElement <"<< qPrintable(eName)
+    qDebug()<< "startElement <"<< eName
 	<<">  state="<<state 
 	<<"  laststate="<<stateStack.last()
 	<<"   loadMode="<<loadMode
-    //	<<"       line="<<QXmlDefaultHandler::lineNumber()
-	<<endl;
+    	//<<"       line="<<QXmlDefaultHandler::lineNumber();
+	<<"contentFilter="<<contentFilter;
     */	
     stateStack.append (state);	
     if ( state == StateInit && (eName == "vymmap")  ) 
@@ -57,74 +70,19 @@ bool parseVYMHandler::startElement  ( const QString&, const QString&,
 	    model->clear();
 	    lastBranch=NULL;
 
-	    if (!atts.value( "author").isEmpty() )
-		model->setAuthor(atts.value( "author" ) );
-	    if (!atts.value( "comment").isEmpty() )
-		model->setComment (atts.value( "comment" ) );
-	    if (!atts.value( "branchCount").isEmpty() )
-	    {
-		branchesTotal=atts.value("branchCount").toInt();
-		if (branchesTotal>10)
-		{
-		    useProgress=true;
-		    mainWindow->setProgressMaximum (branchesTotal);
-		}
-	    } 
-		
-	    if (!atts.value( "backgroundColor").isEmpty() )
-	    {
-		col.setNamedColor(atts.value("backgroundColor"));
-		model->getScene()->setBackgroundBrush(col);
-	    }	    
-	    if (!atts.value( "defaultFont").isEmpty() )
-	    {
-		QFont font (atts.value("defaultFont"));
-		model->setMapDefaultFont (font);
-	    }	    
-	    if (!atts.value( "defaultFontSize").isEmpty() )
-	    {
-		model->setMapDefaultFontSize (atts.value ("defaultFontSize").toDouble() );
-	    }	    
-	    if (!atts.value( "selectionColor").isEmpty() )
-	    {
-		col.setNamedColor(atts.value("selectionColor"));
-		model->setSelectionColor(col);
-	    }	    
-	    if (!atts.value( "linkColorHint").isEmpty() ) 
-	    {
-		if (atts.value("linkColorHint")=="HeadingColor")
-		    model->setMapLinkColorHint(LinkableMapObj::HeadingColor);
-		else
-		    model->setMapLinkColorHint(LinkableMapObj::DefaultColor);
-	    }
-	    if (!atts.value( "linkStyle").isEmpty() ) 
-		model->setMapLinkStyle(atts.value("linkStyle"));
-	    if (!atts.value( "linkColor").isEmpty() ) 
-	    {
-		col.setNamedColor(atts.value("linkColor"));
-		model->setMapDefLinkColor(col);
-	    }	
-	    if (!atts.value( "defXLinkColor").isEmpty() ) 
-	    {
-		col.setNamedColor(atts.value("defXLinkColor"));
-		model->setMapDefXLinkColor(col);
-	    }	
-	    if (!atts.value( "defXLinkWidth").isEmpty() ) 
-		model->setMapDefXLinkWidth(atts.value("defXLinkWidth").toInt ());
-	    if (!atts.value( "mapZoomFactor").isEmpty() ) 
-		model->setMapZoomFactor(atts.value("mapZoomFactor").toDouble());
+	    readMapAttr (atts);
 	}   
 	// Check version
 	if (!atts.value( "version").isEmpty() ) 
 	{
 	    if (!checkVersion(atts.value("version")))
-		QMessageBox::warning( 0, "Warning: Version Problem" ,
-		   "<h3>Map is newer than VYM</h3>"
+		QMessageBox::warning( 0, QObject::tr("Warning: Version Problem") , 
+		   QObject::tr("<h3>Map is newer than VYM</h3>"
 		   "<p>The map you are just trying to load was "
-		   "saved using vym " +atts.value("version")+". "
-		   "The version of this vym is " + vymVersion + 
-		   ". If you run into problems after pressing "
-		   "the ok-button below, updating vym should help.");
+		   "saved using vym %1. "
+		   "The version of this vym is %2. " 
+		   "If you run into problems after pressing "
+		   "the ok-button below, updating vym should help.</p>").arg(atts.value("version")).arg(vymVersion));
 	    else       
 		model->setVersion(atts.value( "version" ));
 
@@ -138,6 +96,18 @@ bool parseVYMHandler::startElement  ( const QString&, const QString&,
 	state=StateMapSetting;
 	if (loadMode==NewMap)
 	    readSettingAttr (atts);
+    } else if ( eName == "slide" && state == StateMap )
+    {
+	state=StateMapSlide;
+	if (!  contentFilter && SlideContent)  
+	{   
+	    // Ignore slides during paste
+	    lastSlide=model->addSlide();
+	    if (insertPos>=0)
+	    model->relinkSlide (lastSlide, insertPos);
+	    
+	    readSlideAttr(atts);
+	}
     } else if ( eName == "mapcenter" && state == StateMap ) 
     {
 	state=StateMapCenter;
@@ -156,25 +126,29 @@ bool parseVYMHandler::startElement  ( const QString&, const QString&,
 		if (loadMode==ImportAdd)
 		{
 		    // Import Add
-		    lastBranch=model->createBranch(lastBranch);
+		    if (insertPos<0) 
+			lastBranch=model->createBranch(lastBranch);
+		    else
+		    {
+			lastBranch=model->addNewBranch(lastBranch, insertPos);
+			insertPos++;
+		    }
 		} else  
 		{
 		    // Import Replace 
-		    if (insertPos<0) 
+		    if (insertPos<0)
 		    {
-			insertPos=lastBranch->num();
+			insertPos=lastBranch->num() +1;
 			model->clearItem (lastBranch);
 		    } else
 		    {
-			TreeItem *pi=lastBranch->parent();
-			if (pi && pi->isBranchLikeType())
-			    lastBranch=model->addNewBranch(insertPos,lastBranch);
-			else
-			    qDebug()<<"xml-vym:  pi is no branch?!";
+			BranchItem *pi=bi->parentBranch();
+			lastBranch=model->addNewBranch(pi, insertPos);
+			insertPos++;
 		    }
 		}
 	    } else
-		// add mapCenter without parent
+		// if nothing selected, add mapCenter without parent
 		lastBranch=model->createMapCenter(); 
 	}	
 	readBranchAttr (atts);
@@ -185,13 +159,17 @@ bool parseVYMHandler::startElement  ( const QString&, const QString&,
 	state=StateStandardFlag;
     } else if ( eName == "heading" && (state == StateMapCenter||state==StateBranch)) 
     {
-	laststate=state;
 	state=StateHeading;
 	if (!atts.value( "textColor").isEmpty() ) 
 	{
 	    col.setNamedColor(atts.value("textColor"));
 	    lastBranch->setHeadingColor(col );
 	}	
+    } else if ( eName == "task" && (state == StateMapCenter||state==StateBranch)) 
+    {
+	state=StateTask;
+	lastTask=taskModel->createTask (lastBranch);
+	if (!readTaskAttr(atts)) return false;
     } else if ( eName == "note" && 
 		(state == StateMapCenter ||state==StateBranch))
     {	// only for backward compatibility (<1.4.6). Use htmlnote now.
@@ -199,7 +177,6 @@ bool parseVYMHandler::startElement  ( const QString&, const QString&,
 	if (!readNoteAttr (atts) ) return false;
     } else if ( eName == "htmlnote" && state == StateMapCenter) 
     {
-	laststate=state;
 	state=StateHtmlNote;
 	no.clear();
 	if (!atts.value( "fonthint").isEmpty() ) 
@@ -207,7 +184,6 @@ bool parseVYMHandler::startElement  ( const QString&, const QString&,
     } else if ( eName == "vymnote" && 
 		(state == StateMapCenter ||state==StateBranch)) 
     {
-	laststate=state;
 	state=StateVymNote;
 	no.clear();
 	if (!atts.value( "fonthint").isEmpty() ) 
@@ -263,18 +239,17 @@ bool parseVYMHandler::startElement  ( const QString&, const QString&,
 	readBranchAttr (atts);
     } else if ( eName == "htmlnote" && state == StateBranch) 
     {
-	laststate=state;
 	state=StateHtmlNote;
 	no.clear();
 	if (!atts.value( "fonthint").isEmpty() ) 
 	    no.setFontHint(atts.value ("fonthint") );
     } else if ( eName == "frame" && (state == StateBranch||state==StateMapCenter)) 
     {
-	laststate=state;
 	state=StateFrame;
 	if (!readFrameAttr(atts)) return false;
     } else if ( eName == "xlink" && state == StateBranch ) 
     {
+	// Obsolete after 1.13.2
 	state=StateBranchXLink;
 	if (!readXLinkAttr (atts)) return false;
     } else if ( eName == "xlink" && state == StateMap) 
@@ -289,9 +264,9 @@ bool parseVYMHandler::startElement  ( const QString&, const QString&,
 	(state == StateHtmlNote || state == StateVymNote) ) 
     {
 	state=StateHtml;
-	textdata="<"+eName;
+	htmldata="<"+eName;
 	readHtmlAttr(atts);
-	textdata+=">";
+	htmldata+=">";
     } else if ( eName == "attribute" && 
 	(state == StateBranch || state == StateMapCenter ) ) 
     {
@@ -312,9 +287,9 @@ bool parseVYMHandler::startElement  ( const QString&, const QString&,
     } else if ( state == StateHtml ) 
     {
 	// accept all while in html mode,
-	textdata+="<"+eName;
+	htmldata+="<"+eName;
 	readHtmlAttr(atts);
-	textdata+=">";
+	htmldata+=">";
     } else
         return false;   // Error
     return true;
@@ -323,49 +298,49 @@ bool parseVYMHandler::startElement  ( const QString&, const QString&,
 bool parseVYMHandler::endElement  ( const QString&, const QString&, const QString &eName)
 {
     /* Testing
-    cout << "endElement </" <<qPrintable(eName)
+    qDebug()<< "endElement </" <<eName
 	<<">  state=" <<state 
-    //	<<"  laststate=" <<laststate
     //	<<"  stateStack="<<stateStack.last() 
-    //	<<"  selString="<<model->getSelectString().toStdString()
-	<<endl;
+    //	<<"  selString="<<model->getSelectString().toStdString();
     */
     switch ( state ) 
     {
 	case StateMap:
 	    break;
         case StateMapCenter: 
-	    model->emitDataHasChanged (lastBranch);
+	    model->emitDataChanged (lastBranch);
 	    lastBranch=(BranchItem*)(lastBranch->parent());
-	//  lastBranch->setLastSelectedBranch (0);  // Reset last selected to first child branch
             break;
         case StateBranch: 
 	    // Empty branches may not be scrolled 
 	    // (happens if bookmarks are imported)
 	    if (lastBranch->isScrolled() && lastBranch->branchCount()==0) 
 		lastBranch->unScroll();
-	    model->emitDataHasChanged (lastBranch);
+	    model->emitDataChanged (lastBranch);
 
 	    lastBranch=(BranchItem*)(lastBranch->parent());
-	    lastBranch->setLastSelectedBranch (0);  // Reset last selected to first child branch
+	    lastBranch->setLastSelectedBranch (0);  
             break;
 	case StateHtmlNote: 
-	    no.setNote (textdata);  // Richtext note, needed anyway for backward compatibility
+	    no.setNote (htmldata);  // Richtext note, needed anyway for backward compatibility
 	    lastBranch->setNoteObj (no);
 	    break;  
+	case StateMapSlide: 
+	    lastSlide=NULL;
+	    break;  
 	case StateVymNote:	    // Might be richtext or plaintext with 
 				    // version >= 1.13.8
-	    no.setNote (textdata);
+	    no.setNote (htmldata);
 	    if (!no.isRichText())
-		no.setNoteMasked (textdata);
+		no.setNoteMasked (htmldata);
 	    lastBranch->setNoteObj (no);
 	    break;  
         case StateHtml: 
-	    textdata+="</"+eName+">";
+	    htmldata+="</"+eName+">";
 	    if (eName=="html")
 	    {
 		//state=StateHtmlNote;  
-		textdata.replace ("<br></br>","<br />");
+		htmldata.replace ("<br></br>","<br />");
 	    }	
 	    break;
 	default: 
@@ -377,7 +352,7 @@ bool parseVYMHandler::endElement  ( const QString&, const QString&, const QStrin
 
 bool parseVYMHandler::characters   ( const QString& ch)
 {
-    //cout << "characters \""<<ch.toStdString()<<"\"  state="<<state <<"  laststate="<<laststate<<endl;
+    //qDebug()<< "xml-vym: characters \""<<ch<<"\"  state="<<state;
 
     QString ch_org=quotemeta (ch);
     QString ch_simplified=ch.simplified();
@@ -401,13 +376,13 @@ bool parseVYMHandler::characters   ( const QString& ch)
             break;
         case StateImage: break;
         case StateVymNote: 
-	    textdata=ch;
+	    htmldata=ch;
 	    break;
         case StateHtmlNote: 
-	    textdata=ch;
+	    htmldata=ch;
 	    break;
         case StateHtml:
-	    textdata+=ch_org;
+	    htmldata+=ch_org;
 	    break;
         case StateHeading: 
             lastBranch->setHeading(ch);
@@ -423,6 +398,78 @@ QString parseVYMHandler::errorString()
     return "the document is not in the VYM file format";
 }
 
+bool parseVYMHandler::readMapAttr (const QXmlAttributes& a)	
+{
+    QColor col;
+    if (!a.value( "author").isEmpty() )  
+	model->setAuthor(a.value( "author" ) );
+    if (!a.value( "comment").isEmpty() )
+	model->setComment (a.value( "comment" ) );
+    if (!a.value( "branchCount").isEmpty() )
+    {
+	branchesTotal=a.value("branchCount").toInt();
+	if (branchesTotal>10)
+	{
+	    useProgress=true;
+	    mainWindow->setProgressMaximum (branchesTotal);
+	}
+    } 
+	
+    if (!a.value( "backgroundColor").isEmpty() )
+    {
+	col.setNamedColor(a.value("backgroundColor"));
+	model->getScene()->setBackgroundBrush(col);
+    }	    
+    if (!a.value( "defaultFont").isEmpty() )
+    {
+	QFont font;
+	font.fromString(a.value("defaultFont"));
+	model->setMapDefaultFont (font);
+    }	    
+    if (!a.value( "selectionColor").isEmpty() )
+    {
+	col.setNamedColor(a.value("selectionColor"));
+	model->setSelectionColor(col);
+    }	    
+    if (!a.value( "linkColorHint").isEmpty() ) 
+    {
+	if (a.value("linkColorHint")=="HeadingColor")
+	    model->setMapLinkColorHint(LinkableMapObj::HeadingColor);
+	else
+	    model->setMapLinkColorHint(LinkableMapObj::DefaultColor);
+    }
+    if (!a.value( "linkStyle").isEmpty() ) 
+	model->setMapLinkStyle(a.value("linkStyle"));
+    if (!a.value( "linkColor").isEmpty() ) 
+    {
+	col.setNamedColor(a.value("linkColor"));
+	model->setMapDefLinkColor(col);
+    }	
+
+    QPen pen (model->getMapDefXLinkPen() );
+    if (!a.value( "defXLinkColor").isEmpty() ) 
+    {
+	col.setNamedColor(a.value("defXLinkColor"));
+	pen.setColor(col);
+    }	
+    if (!a.value( "defXLinkWidth").isEmpty() ) 
+	pen.setWidth(a.value("defXLinkWidth").toInt ());
+    if (!a.value( "defXLinkPenStyle").isEmpty() ) 
+    {	
+	bool ok;
+	Qt::PenStyle ps=penStyle (a.value("defXLinkPenStyle"),ok );
+	if (!ok) return false;
+	pen.setStyle (ps);
+    }
+    model->setMapDefXLinkPen (pen);
+
+    if (!a.value( "mapZoomFactor").isEmpty() ) 
+	model->setMapZoomFactor(a.value("mapZoomFactor").toDouble());
+    if (!a.value( "mapRotationAngle").isEmpty() ) 
+	model->setMapRotationAngle(a.value("mapRotationAngle").toDouble());
+    return true;
+}
+
 bool parseVYMHandler::readBranchAttr (const QXmlAttributes& a)	
 {
     branchesCounter++;
@@ -451,6 +498,8 @@ bool parseVYMHandler::readBranchAttr (const QXmlAttributes& a)
 	else	
 	    lastBranch->setIncludeImagesHor(false);
     }	
+    if (!a.value( "uuid").isEmpty() ) 
+	lastBranch->setUuid (a.value( "uuid") );
     return true;    
 }
 
@@ -546,6 +595,14 @@ bool parseVYMHandler::readOOAttr (const QXmlAttributes& a)
 	if (!a.value( "localTarget").isEmpty() )
 	    if (a.value ("localTarget")=="true")
 		lastMI->toggleTarget();
+	if (!a.value( "rotation").isEmpty() ) 
+	{
+	    x=a.value("rotation").toFloat (&okx);
+	    if (okx )
+		lastMI->setRotation (x);
+	    else	
+		return false;   // Couldn't read rotation
+	}           
     }
     return true;    
 }
@@ -646,8 +703,42 @@ bool parseVYMHandler::readImageAttr (const QXmlAttributes& a)
 
 bool parseVYMHandler::readXLinkAttr (const QXmlAttributes& a) 
 {
-    // Format of links was changed several times:
-    //
+    // Obsolete, see also readLinkAttr
+
+    if (!a.value( "beginID").isEmpty() ) 
+    { 
+	if (!a.value( "endID").isEmpty() ) 
+	{
+	    TreeItem *beginBI=model->findBySelectString (a.value( "beginID"));
+	    TreeItem   *endBI=model->findBySelectString (a.value( "endID"));
+	    if (beginBI && endBI && beginBI->isBranchLikeType() && endBI->isBranchLikeType() )
+	    {
+		Link *li=new Link (model);
+		li->setBeginBranch ( (BranchItem*)beginBI );
+		li->setEndBranch ( (BranchItem*)endBI);
+		QPen pen=li->getPen();
+
+		if (!a.value( "color").isEmpty() ) 
+		{
+		    QColor col;
+		    col.setNamedColor(a.value("color"));
+		    pen.setColor (col);
+		}
+
+		if (!a.value( "width").isEmpty() ) 
+		{
+		    bool okx;
+		    pen.setWidth(a.value ("width").toInt (&okx, 10));
+		}
+		model->createLink (li,true);	// create MO by default
+	    }
+	}           
+    }	
+    return true;    
+}
+
+bool parseVYMHandler::readLinkNewAttr (const QXmlAttributes& a)	
+{
     // object ID is used starting in version 1.8.76
     // (before there was beginBranch and endBranch)
     //
@@ -667,71 +758,48 @@ bool parseVYMHandler::readXLinkAttr (const QXmlAttributes& a)
 		li->setBeginBranch ( (BranchItem*)beginBI );
 		li->setEndBranch ( (BranchItem*)endBI);
 
+		bool okx;
+		QPen pen=li->getPen();
+		if (!a.value( "type").isEmpty() ) 
+		{
+		    li->setLinkType (a.value( "type") );
+		}
 		if (!a.value( "color").isEmpty() ) 
 		{
 		    QColor col;
 		    col.setNamedColor(a.value("color"));
-		    li->setColor (col);
+		    pen.setColor (col);
 		}
 
 		if (!a.value( "width").isEmpty() ) 
 		{
-		    bool okx;
-		    li->setWidth(a.value ("width").toInt (&okx, 10));
+		    pen.setWidth(a.value ("width").toInt (&okx, 10));
 		}
+		if (!a.value( "penstyle").isEmpty() ) 
+		{
+		    pen.setStyle( penStyle (a.value ("penstyle"), okx));
+		}
+		li->setPen (pen);
+
 		model->createLink (li,true);	// create MO by default
+
+		XLinkObj *xlo=(XLinkObj*)(li->getMO() );
+		if (xlo && !a.value( "c0").isEmpty() )
+		{
+		    QPointF p=point(a.value("c0"),okx );
+		    if (okx) xlo->setC0 (p);
+		}
+		if (xlo && !a.value( "c1").isEmpty() )
+		{
+		    QPointF p=point(a.value("c1"),okx );
+		    if (okx) xlo->setC1 (p);
+		}
 	    }
 	}           
     }	
     return true;    
 }
 
-bool parseVYMHandler::readLinkNewAttr (const QXmlAttributes& a)	
-{
-    // object ID is used starting in version 1.8.76
-    // (before there was beginBranch and endBranch)
-
-    // Beginning in 1.13.2 xLinks are no longer parts of branches, but
-    // a separate list after all the mapCenters within <vymmap> ... </vymmap>
-
-    if (!a.value( "beginID").isEmpty() ) 
-    { 
-	if (!a.value( "endID").isEmpty() ) 
-	{
-	    TreeItem *beginBI=model->findBySelectString (a.value( "beginID"));
-	    TreeItem   *endBI=model->findBySelectString (a.value( "endID"));
-	    if (beginBI && endBI && beginBI->isBranchLikeType() && endBI->isBranchLikeType() )
-	    {
-		Link *li=new Link (model);
-		li->setBeginBranch ( (BranchItem*)beginBI );
-		li->setEndBranch ( (BranchItem*)endBI);
-
-		if (!a.value( "color").isEmpty() ) 
-		{
-		    QColor col;
-		    col.setNamedColor(a.value("color"));
-		    li->setColor (col);
-		}
-
-		if (!a.value( "width").isEmpty() ) 
-		{
-		    bool okx;
-		    li->setWidth(a.value ("width").toInt (&okx, 10));
-		}
-		model->createLink (li,true);	// create MO by default
-	    }
-	}           
-    }	
-    return true;    
-}
-
-bool parseVYMHandler::readHtmlAttr (const QXmlAttributes& a)
-{
-    for (int i=1; i<=a.count(); i++)
-	textdata+=" "+a.localName(i-1)+"=\""+a.value(i-1)+"\"";
-    return true;
-}
-
 bool parseVYMHandler::readSettingAttr (const QXmlAttributes& a)
 {
     if (!a.value( "key").isEmpty() ) 
@@ -746,3 +814,79 @@ bool parseVYMHandler::readSettingAttr (const QXmlAttributes& a)
     
     return true;
 }
+
+bool parseVYMHandler::readSlideAttr (const QXmlAttributes& a)
+{
+    QStringList scriptlines;	// FIXME-3 needed for switching to inScript
+                                // Most attributes are obsolete with inScript
+    if (!lastSlide) return false;
+    {
+	if (!a.value( "name").isEmpty() ) 
+	    lastSlide->setName (a.value( "name" ) );
+	if (!a.value( "zoom").isEmpty() ) 
+	{
+	    bool ok;
+	    qreal z=a.value ("zoom").toDouble(&ok);
+	    if (!ok) return false;
+	    scriptlines.append( QString("setMapZoom(%1)").arg(z) );
+	}
+	if (!a.value( "rotation").isEmpty() ) 
+	{
+	    bool ok;
+	    qreal z=a.value ("rotation").toDouble(&ok);
+	    if (!ok) return false;
+	    scriptlines.append( QString("setMapRotation(%1)").arg(z) );
+	}
+	if (!a.value( "duration").isEmpty() ) 
+	{
+	    bool ok;
+	    int d=a.value ("duration").toInt(&ok);
+	    if (!ok) return false;
+	    scriptlines.append( QString("setMapAnimDuration(%1)").arg(d) );
+	}
+	if (!a.value( "curve").isEmpty() ) 
+	{
+	    bool ok;
+	    int i=a.value ("curve").toInt(&ok);
+	    if (!ok ) return false;
+	    if (i<0 || i>QEasingCurve::OutInBounce) return false;
+	    scriptlines.append( QString("setMapAnimCurve(%1)").arg(i) );
+	}
+	if (!a.value( "mapitem").isEmpty() ) 
+	{
+	    TreeItem *ti=model->findBySelectString ( a.value( "mapitem") );
+	    if (!ti) return false;
+	    scriptlines.append( QString("centerOnID(\"%1\")").arg(ti->getUuid().toString() ) );
+	}
+	if (!a.value( "inScript").isEmpty() ) 
+	{
+	    lastSlide->setInScript( unquotemeta( a.value( "inScript") ) );
+	} else
+	    lastSlide->setInScript( unquotemeta( scriptlines.join(";\n") ) );
+
+	if (!a.value( "outScript").isEmpty() ) 
+	{
+	    lastSlide->setOutScript( unquotemeta( a.value( "outScript") ) );
+	}
+    }
+    return true;
+}
+
+bool parseVYMHandler::readTaskAttr (const QXmlAttributes& a)
+{
+    if (!lastTask) return false;
+    {
+	if (!a.value( "status").isEmpty() ) 
+	    lastTask->setStatus (a.value( "status" ) );
+	if (!a.value( "awake").isEmpty() ) 
+	    lastTask->setAwake (a.value( "awake" ) );
+	if (!a.value( "date_creation").isEmpty() ) 
+	    lastTask->setDateCreation ( a.value( "date_creation" ) );
+	if (!a.value( "date_modified").isEmpty() ) 
+	    lastTask->setDateModified( a.value( "date_modified" ) );
+	if (!a.value( "date_sleep").isEmpty() ) 
+	    lastTask->setDateSleep( a.value( "date_sleep" ) );
+    }
+    return true;
+}
+
